package com.fs.crm.service;

import com.fs.crm.domain.CrmCustomerUser;

import java.util.List;

/**
 * 客户员工认领Service接口
 *
 * @author fs
 * @date 2022-12-21
 */
public interface ICrmCustomerUserService
{
    /**
     * 查询客户员工认领
     *
     * @param customerUserId 客户员工认领ID
     * @return 客户员工认领
     */
    public CrmCustomerUser selectCrmCustomerUserById(Long customerUserId);

    /**
     * 查询客户员工认领列表
     *
     * @param crmCustomerUser 客户员工认领
     * @return 客户员工认领集合
     */
    public List<CrmCustomerUser> selectCrmCustomerUserList(CrmCustomerUser crmCustomerUser);

    /**
     * 新增客户员工认领
     *
     * @param crmCustomerUser 客户员工认领
     * @return 结果
     */
    public int insertCrmCustomerUser(CrmCustomerUser crmCustomerUser);

    /**
     * 修改客户员工认领
     *
     * @param crmCustomerUser 客户员工认领
     * @return 结果
     */
    public int updateCrmCustomerUser(CrmCustomerUser crmCustomerUser);

    /**
     * 批量删除客户员工认领
     *
     * @param customerUserIds 需要删除的客户员工认领ID
     * @return 结果
     */
    public int deleteCrmCustomerUserByIds(Long[] customerUserIds);

    /**
     * 删除客户员工认领信息
     *
     * @param customerUserId 客户员工认领ID
     * @return 结果
     */
    public int deleteCrmCustomerUserById(Long customerUserId);

    Integer selectCrmMyCustomerUserCount(Long companyId, long userId);
}
